==> apache-cxf-3.6.5-src.zip: apache-cxf-3.6.5-src/rt/rs/security/oauth-parent/oauth2/src/main/java/org/apache/cxf/rs/security/oauth2/client/ClientTokenContextImpl.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.rs.security.oauth2.client;

import javax.ws.rs.core.MultivaluedMap;

import org.apache.cxf.rs.security.oauth2.common.ClientAccessToken;

public class ClientTokenContextImpl implements ClientTokenContext {
    private static final long serialVersionUID = -3501237730333195311L;
    private ClientAccessToken token;
    private MultivaluedMap<String, String> state;

    public ClientAccessToken getToken() {
        return token;
    }

    public void setToken(ClientAccessToken token) {
        this.token = token;
    }

    public MultivaluedMap<String, String> getState() {
        return state;
    }

    public void setState(MultivaluedMap<String, String> state) {
        this.state = state;
    }

    @SuppressWarnings("unchecked")
    public <T> T getState(Class<T> cls) {
        if (MultivaluedMap.class == cls) {
            return (T)state;
        }
        return null;
    }
}

==> apache-cxf-4.1.2-src.zip: apache-cxf-4.1.2-src/rt/rs/security/oauth-parent/oauth2/src/main/java/org/apache/cxf/rs/security/oauth2/client/ClientTokenContextImpl.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.rs.security.oauth2.client;

import jakarta.ws.rs.core.MultivaluedMap;
import org.apache.cxf.rs.security.oauth2.common.ClientAccessToken;

public class ClientTokenContextImpl implements ClientTokenContext {
    private static final long serialVersionUID = -3501237730333195311L;
    private ClientAccessToken token;
    private MultivaluedMap<String, String> state;

    public ClientAccessToken getToken() {
        return token;
    }

    public void setToken(ClientAccessToken token) {
        this.token = token;
    }

    public MultivaluedMap<String, String> getState() {
        return state;
    }

    public void setState(MultivaluedMap<String, String> state) {
        this.state = state;
    }

    @SuppressWarnings("unchecked")
    public <T> T getState(Class<T> cls) {
        if (MultivaluedMap.class == cls) {
            return (T)state;
        }
        return null;
    }
}
